@@ -73,8 +73,8 @@ class Image(object):
         return c
 
     def in_engine_cache(self):
-        return len(self.engine_client.images(name=self.canonical_name,
-                                             quiet=True)) == 1
+        return len(self.engine_client.images.list(
+            name=self.canonical_name)) >= 1
 
     def __repr__(self):
         return ("Image(%s, %s, %s, parent_name=%s,"
@@ -118,7 +118,7 @@ class KollaWorker(object):
             self.distro_package_manager = 'dnf'
             self.base_package_type = 'rpm'
         elif self.base in ['debian']:
-            self.conf.distro_python_version = "3.9"
+            self.conf.distro_python_version = "3.11"
             self.distro_package_manager = 'apt'
             self.base_package_type = 'deb'
         elif self.base in ['ubuntu']:
